# Enabled by default
%bcond_without tests

%global pypi_name ConfigUpdater
%global lower_name configupdater

%global _description %{expand:
The sole purpose of ConfigUpdater is to easily update an INI config file with
no changes to the original file except the intended ones. This means comments,
the ordering of sections and key/value-pairs as well as their cases are kept
as in the original file. Thus ConfigUpdater provides complementary
functionality to Python’s ConfigParser which is primarily meant for reading
config files and writing new ones.

Features
The key differences to ConfigParser are:

- minimal invasive changes in the update configuration file,
- proper handling of comments,
- only a single config file can be updated at a time,
- the original case of sections and keys are kept,
- control over the position of a new section/key

Following features are deliberately not implemented:

- interpolation of values,
- propagation of parameters from the default section,
- conversions of values,
- passing key/value-pairs with default argument,
- non-strict mode allowing duplicate sections and keys.}

Name:           python-%{lower_name}
Version:        2.0
Release:        1%{?dist}
Summary:        Parser like ConfigParser but for updating configuration files

License:        MIT
URL:            https://pypi.org/pypi/%{pypi_name}
Source0:        %pypi_source

BuildArch:      noarch

%description %_description

%package -n python3-%{pypi_name}
Summary:        %{summary}
BuildRequires:  make
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  %{py3_dist pytest}

%description -n python3-%{pypi_name} %_description

%package doc
Summary:        Documentation for %{name}
BuildRequires:  python3-sphinx

%description doc
This package provides generated documentation for %{name}.

%prep
%autosetup -n %{pypi_name}-%{version}
rm -rf %{pypi_name}.egg-info

# Remove coverage bits
sed -i '/--cov/ d' setup.cfg

# Comment out to remove /usr/bin/env shebangs
# Can use something similar to correct/remove /usr/bin/python shebangs also
# find . -type f -name "*.py" -exec sed -i '/^#![  ]*\/usr\/bin\/env.*$/ d' {} 2>/dev/null ';'

%build
%py3_build

make -C docs SPHINXBUILD=sphinx-build-3 html
rm -rf docs/_build/html/{.doctrees,.buildinfo} -vf

%install
%py3_install

%check
%if %{with tests}
%{pytest}
%endif

%files -n python3-%{pypi_name}
%license LICENSE.txt
%doc README.rst AUTHORS.rst CHANGELOG.rst CONTRIBUTING.rst
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info
%{python3_sitelib}/%{lower_name}

%files doc
%license LICENSE.txt
%doc docs/_build/html

%changelog
* Wed Jul 07 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0-1
- minor typo fixes
- improve doc sub-package summary

* Wed Jul 07 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0-1
- improve doc package description
- add space in package description

* Tue Jul 06 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.0-1
- Initial build

